@@ -58,20 +58,43 @@ class BaseExporter(object):
             yield formatter(values, preferred_formats=self.preferred_formats,
                             **kwargs)
 
-    def read(self, iterable, force_distinct=True, *args, **kwargs):
+    def read(self, iterable, force_distinct=True, offset=None, limit=None,
+             *args, **kwargs):
         """Takes an iterable that produces rows to be formatted.
 
         If `force_distinct` is true, rows will be filtered based on the slice
-        of the row that is *up* for to be formatted. Note, this assumes the
-        rows are ordered.
+        of the row that is going to be formatted.
+
+        If `offset` is defined, only rows that are produced after the offset
+        index are returned.
+
+        If `limit` is defined, once the limit has been reached (or the
+        iterator is exhausted), the loop will exit.
         """
-        last_row = None
-        for row in iterable:
+        emitted = 0
+        unique_rows = set()
+
+        for i, row in enumerate(iterable):
+            if limit is not None and emitted >= limit:
+                break
+
             _row = row[:self.row_length]
-            if force_distinct and _row == last_row:
-                continue
-            last_row = _row
-            yield self._format_row(_row, **kwargs)
+
+            if force_distinct:
+                _row_hash = hash(tuple(_row))
+
+                if _row_hash in unique_rows:
+                    continue
+
+                unique_rows.add(_row_hash)
+
+            if offset is None or i >= offset:
+                emitted += 1
+                yield self._format_row(_row, **kwargs)
 
     def write(self, iterable, *args, **kwargs):
-        raise NotImplemented
+        for row_gen in self.read(iterable, *args, **kwargs):
+            row = []
+            for data in row_gen:
+                row.extend(data.values())
+            yield tuple(row)
